@@ -1,7 +1,7 @@
 __all__ = ('Drive', 'DriveFactory')
 
 
-from typing import List, AsyncGenerator, Tuple, Optional, Type
+from typing import List, AsyncGenerator, Tuple, Optional, Type, Union
 import asyncio
 import concurrent.futures
 import contextlib
@@ -35,6 +35,7 @@ from .util import (
     get_default_config_path,
     get_default_data_path,
     import_class,
+    is_valid_name,
     normalize_path,
     resolve_path,
 )
@@ -93,10 +94,10 @@ class Drive(object):
         self._context = context
         self._sync_lock = asyncio.Lock()
 
-        self._remote = None
+        self._remote: Union[RemoteDriver, None] = None
 
         self._pool = None
-        self._db = None
+        self._db: Union[Cache, None] = None
 
         self._raii = None
 
@@ -219,12 +220,16 @@ class Drive(object):
     ) -> Node:
         '''Create a folder.'''
         # sanity check
+        if not self._remote:
+            raise InvalidRemoteDriverError()
         if not parent_node:
             raise TypeError('invalid parent node')
         if not parent_node.is_folder:
             raise ParentIsNotFolderError('invalid parent node')
         if not folder_name:
             raise TypeError('invalid folder name')
+        if not is_valid_name(folder_name):
+            raise TypeError('invalid folder name: no `/` or `\\` allowed')
 
         if not exist_ok:
             node = await self.get_node_by_name_from_parent(
@@ -249,6 +254,8 @@ class Drive(object):
     async def download(self, node: Node) -> ReadableFile:
         '''Download the node.'''
         # sanity check
+        if not self._remote:
+            raise InvalidRemoteDriverError()
         if not node:
             raise TypeError('node is none')
         if node.is_folder:
@@ -284,12 +291,16 @@ class Drive(object):
     ) -> WritableFile:
         '''Upload file.'''
         # sanity check
+        if not self._remote:
+            raise InvalidRemoteDriverError()
         if not parent_node:
             raise TypeError('invalid parent node')
         if not parent_node.is_folder:
             raise ParentIsNotFolderError('invalid parent node')
         if not file_name:
             raise TypeError('invalid file name')
+        if not is_valid_name(file_name):
+            raise TypeError('invalid file name: no `/` or `\\` allowed')
 
         node = await self.get_node_by_name_from_parent(file_name, parent_node)
         if node:
@@ -312,6 +323,8 @@ class Drive(object):
     async def trash_node(self, node: Node) -> None:
         '''Move the node to trash.'''
         # sanity check
+        if not self._remote:
+            raise InvalidRemoteDriverError()
         if not node:
             raise TypeError('source node is none')
         root_node = await self.get_root_node()
@@ -326,6 +339,8 @@ class Drive(object):
     ) -> Node:
         '''Move or rename the node.'''
         # sanity check
+        if not self._remote:
+            raise InvalidRemoteDriverError()
         if not node:
             raise TypeError('source node is none')
         if node.trashed:
@@ -337,6 +352,9 @@ class Drive(object):
         if not new_parent and not new_name:
             raise TypeError('need new_parent or new_name')
 
+        if new_name and not is_valid_name(new_name):
+            raise TypeError('invalid new name: no `/` or `\\` allowed')
+
         if new_parent:
             if new_parent.trashed:
                 raise TrashedNodeError('new_parent is in trash')
@@ -431,6 +449,8 @@ class Drive(object):
 
         This is the ONLY function which will modify the local cache.
         '''
+        if not self._remote:
+            raise InvalidRemoteDriverError()
         async with self._sync_lock:
             dry_run = check_point is not None
             initial_check_point = await self._remote.get_initial_check_point()
@@ -455,6 +475,8 @@ class Drive(object):
 
     async def get_hasher(self) -> Hasher:
         '''Get a Hasher instance for checksum calculation.'''
+        if not self._remote:
+            raise InvalidRemoteDriverError()
         return await self._remote.get_hasher()
 
 
